@@ -24,16 +24,23 @@ class SeekPaginator(object):
             return [lookup_field_desc, ]
 
     def prepare_lookup(self, value, pk):
+        """
+        Lookup:
+
+        ...
+        WHERE date <= ?
+        AND NOT (date = ? AND id >= ?)
+        ORDER BY date DESC, id DESC
+        """
         if self.lookup_field not in ("pk", "id"):
             lookup = "%s__lte" % self.lookup_field
-            lookup_filter = {lookup: value, }
             lookup_exclude = {self.lookup_field: value, "pk__gte": pk, }
-            return lookup_filter, lookup_exclude
         else:
             lookup = "%s__lt" % self.lookup_field
-            lookup_filter = {lookup: value, }
             lookup_exclude = None
-            return lookup_filter, lookup_exclude
+
+        lookup_filter = {lookup: value, }
+        return lookup_filter, lookup_exclude
 
     def page(self, value=None, pk=None):
         if (value is None and pk is not None) or (value is not None and pk is None):
